==> 0.1.47.tar.gz: lib/pages/video&picture.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:photo_view/photo_view.dart';
// import 'package:cached_network_image/cached_network_image.dart';
import 'package:video_player/video_player.dart';

class VideoAndPicture extends StatelessWidget {
  const VideoAndPicture({
    Key key,
    @required this.image,
    @required this.title,
    this.controller,
  }) : super(key: key);
  final String image;
  final String title;
  final VideoPlayerController controller;
  @override
  Widget build(BuildContext context) {
    return Directionality(
        textDirection: TextDirection.ltr,
        child: ScreenUtilInit(
          designSize: Size(375.0, 812.0),
          allowFontScaling: false,
          builder: () => Scaffold(
            backgroundColor: Colors.black,
            appBar: AppBar(
              leading: Padding(
                padding: EdgeInsets.only(
                  top: ScreenUtil().setWidth(9),
                ),
                child: IconButton(
                  onPressed: () {
                    Navigator.pop(context);
                  },
                  icon: Icon(Icons.arrow_back, color: Colors.white),
                ),
              ),
              title: Padding(
                padding: EdgeInsets.only(
                  top: ScreenUtil().setWidth(9),
                ),
                child: Text(
                  this.title,
                ),
              ),
              backgroundColor: Colors.black,
            ),
            body: PhotoView.customChild(
                child: Image(
                  image: NetworkImage(this.image),
                  width: double.infinity,
                  fit: BoxFit.fitWidth,
                ),
                backgroundDecoration: BoxDecoration(
                  color: Colors.transparent,
                ),
                heroAttributes: PhotoViewHeroAttributes(
                  tag: 'image${this.title}',
                )
                // imageProvider: CachedNetworkImageProvider(
                //   this.title == "Play" ? this.image : this.image,
                // ),
                ),
          ),
        ));
  }
}

==> 0.2.11.tar.gz: lib/pages/video&picture.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:photo_view/photo_view.dart';
// import 'package:cached_network_image/cached_network_image.dart';
import 'package:video_player/video_player.dart';

class VideoAndPicture extends StatelessWidget {
  const VideoAndPicture({
    Key key,
    @required this.image,
    @required this.title,
    this.controller,
  }) : super(key: key);
  final String image;
  final String title;
  final VideoPlayerController controller;
  @override
  Widget build(BuildContext context) {
    var width = MediaQuery.of(context).size.width;
    var height = MediaQuery.of(context).size.height;
    return Directionality(
        textDirection: TextDirection.ltr,
        child: ScreenUtilInit(
          designSize: Size(width, height),
          allowFontScaling: false,
          builder: () => Scaffold(
            backgroundColor: Colors.black,
            appBar: AppBar(
              leading: Padding(
                padding: EdgeInsets.only(
                  top: ScreenUtil().setWidth(9),
                ),
                child: IconButton(
                  onPressed: () {
                    Navigator.pop(context);
                  },
                  icon: Icon(Icons.arrow_back, color: Colors.white),
                ),
              ),
              title: Padding(
                padding: EdgeInsets.only(
                  top: ScreenUtil().setWidth(9),
                ),
                child: Text(
                  this.title,
                ),
              ),
              backgroundColor: Colors.black,
            ),
            body: PhotoView.customChild(
                child: Image(
                  image: NetworkImage(this.image),
                  width: double.infinity,
                  fit: BoxFit.fitWidth,
                ),
                backgroundDecoration: BoxDecoration(
                  color: Colors.transparent,
                ),
                heroAttributes: PhotoViewHeroAttributes(
                  tag: 'image${this.title}',
                )
                // imageProvider: CachedNetworkImageProvider(
                //   this.title == "Play" ? this.image : this.image,
                // ),
                ),
          ),
        ));
  }
}
